Skip to contents

Reports whether Python and required modules for ustat() are available, including the detected PyTorch version and whether CUDA (GPU acceleration) can be used.

Usage

check_ustats_setup()

Value

Invisibly returns TRUE if environment is ready

Details

Note that with reticulate (>= 1.41), calling this function may initialize Python and trigger the automatic, one-time provisioning of the declared Python dependencies if no Python environment is configured yet (this can involve a sizeable download the first time).

Examples

if (FALSE) { # \dontrun{
check_ustats_setup()
} # }